#!/usr/bin/env bash

#
# Define a function to cleanup working directory
#
function cleanup {
  rm -rf "$WORK_DIR"
  echo "Deleted temp working directory $WORK_DIR"
}
trap cleanup EXIT INT

#
# Load configuration information
#

## Regular one
#source /etc/sysconfig/sbblupdater

## Debug statement
source ./sbblupdater.conf

#
# Create TEMP directory
#
echo 'Creating TEMP directory...'
WORK_DIR=`mktemp -d -p /tmp bl_staging.XXXXXXX`
cd ${WORK_DIR}

if [ "${DEBUG}" = '1' ]; then
	curr_wd=`pwd`
	echo "DEBUG: Current directory: ${curr_wd}"
fi


#
# Download blacklist
#
## Debug variable
#blacklist_url=https://www.lhprojects.net/blacklist/shallalist.tar.gz
echo "Downloading blacklist from ${blacklist_url}"

## Regular one
wget -nv ${blacklist_url}
exit_status=$?

if [ ${exit_status} != 0 ]; then
	echo "ERROR: Unable to download blacklist"
	exit
fi

#
# Extract tar
#
tar xvf shallalist.tar.gz > /dev/null

if [ "${DEBUG}" = '1' ]; then
	curr_wd=`pwd`
	echo "DEBUG: Current directory: ${curr_wd}"
fi

#
# Create domain and url list for each instance then import into SquidBlocker
#
sb_int=0
empty_vars=0
while true; do
	## If there more than 5 consecutive empty sb_url variables, exit out of the loop
	if [ $empty_vars -gt 5 ]; then
		break
	fi
	if [ -z "${sb_url[sb_int]}" ]; then
		((empty_vars++))
		((sb_int++))
		continue
	fi

	echo "Creating blacklists for instance ${sb_int}"
	domains_file=`mktemp domains.XXXX`; domains_file="${WORK_DIR}/${domains_file}"
	urls_file=`mktemp urls.XXXX`; urls_file="${WORK_DIR}/${urls_file}"
	
	for bl in ${blacklists[sb_int]}; do
		cat "BL/${bl}/domains" >> ${domains_file}
		cat "BL/${bl}/urls" >> ${urls_file}

		if [ "${DEBUG}" = '1' ]; then
			linecount=`wc -l ${domains_file}`
			printf "DEBUG: %s has %d domains for instance ${sb_int}\n" ${domains_file} ${linecount}
			linecount=`wc -l ${urls_file}`
			printf "DEBUG: %s has %d urls for instance ${sb_int}\n" ${urls_file} ${linecount}
		fi
	done

	echo "Importing blacklist into instance ${sb_int}..."
	curl -i -X POST -H "Content-Type: multipart/form-data" \
	-F "prefix=dom:" \
	-F "val=1" \
	-F "listfile=@${domains_file}" \
	${sb_url[sb_int]}
	curl -i -X POST -H "Content-Type: multipart/form-data" \
	-F "prefix=url:http://" \
	-F "val=1" \
	-F "listfile=@${urls_file}" \
	${sb_url[sb_int]}

	rm -f ${domains_file}
	rm -f ${urls_file}
	((sb_int++))
done


